# rs3clans.py
[![PyPI](https://img.shields.io/pypi/v/rs3clans.svg)](https://pypi.org/project/rs3clans/) [![PyPI - Python Version](https://img.shields.io/pypi/pyversions/rs3clans.svg)](https://pypi.org/project/rs3clans/)

A Python 3 module wrapper for RuneScape 3 Clan's API

***
## Requirements:

`Python>=3.6`
`requests>=requests==2.19.1`

***

## Setup:

```bash
$ python3 -m pip install rs3clans
```

***

### Documentation (with examples of usage):
[![Docs](https://readthedocs.org/projects/rs3clanspy/badge/?version=latest)](https://rs3clanspy.readthedocs.io/en/latest/?badge=latest)
